var test = require('blue-tape');
var Promise = require('native-or-bluebird');
var os_1 = require('os');
var path_1 = require('path');
var compile_1 = require('./compile');
var config_1 = require('../utils/config');
var fs_1 = require('../utils/fs');
var FIXTURES_DIR = path_1.join(__dirname, '__test__/fixtures');
test('compile', function (t) {
    t.test('fixtures', function (t) {
        t.test('compile a normal definition', function (t) {
            var FIXTURE_DIR = path_1.join(FIXTURES_DIR, 'compile');
            var root = {
                type: config_1.PROJECT_NAME,
                src: path_1.join(FIXTURE_DIR, config_1.CONFIG_FILE),
                missing: false,
                ambient: false,
                main: 'root',
                browser: {
                    b: 'browser'
                },
                dependencies: {},
                devDependencies: {},
                ambientDependencies: {}
            };
            var a = {
                type: config_1.PROJECT_NAME,
                src: path_1.join(FIXTURE_DIR, "a/" + config_1.CONFIG_FILE),
                missing: false,
                ambient: false,
                main: undefined,
                typings: 'typed.d.ts',
                browserTypings: 'typed.browser.d.ts',
                dependencies: {},
                devDependencies: {},
                ambientDependencies: {}
            };
            var b = {
                type: config_1.PROJECT_NAME,
                src: path_1.join(FIXTURE_DIR, 'bower.json'),
                missing: false,
                ambient: false,
                main: undefined,
                typings: 'typings/b.d.ts',
                dependencies: {},
                devDependencies: {},
                ambientDependencies: {}
            };
            var browser = {
                type: config_1.PROJECT_NAME,
                src: path_1.join(FIXTURE_DIR, 'package.json'),
                missing: false,
                ambient: false,
                main: undefined,
                typings: 'browser.d.ts',
                dependencies: {},
                devDependencies: {},
                ambientDependencies: {}
            };
            var dep = {
                type: config_1.PROJECT_NAME,
                src: path_1.join(FIXTURE_DIR, "dep/" + config_1.CONFIG_FILE),
                missing: false,
                ambient: false,
                main: 'dep/main.d.ts',
                dependencies: {},
                devDependencies: {},
                ambientDependencies: {}
            };
            root.dependencies.a = a;
            root.dependencies.b = b;
            root.dependencies.dep = dep;
            root.dependencies.browser = browser;
            return compile_1.default(root, { name: 'root', cwd: __dirname, ambient: false })
                .then(function (result) {
                t.equal(result.main, [
                    'declare module \'root!a\' {',
                    'export interface ITest {',
                    '  foo: string',
                    '  bar: boolean',
                    '}',
                    'export default function (): ITest',
                    '}',
                    'declare module \'root!b\' {',
                    'export const foo: number',
                    '}',
                    'declare module \'root!dep/path\' {',
                    'export const isDep: boolean',
                    '}',
                    'declare module \'root/root-import\' {',
                    'export const test: string',
                    '}',
                    'declare module \'root/root\' {',
                    'import a from \'root!a\'',
                    'import b = require(\'root!b\')',
                    'import { isDep } from \'root!dep/path\'',
                    'export * from \'root/root-import\'',
                    '}',
                    'declare module \'root\' {',
                    'export * from \'root/root\';',
                    '}'
                ].join(os_1.EOL));
                t.equal(result.browser, [
                    'declare module \'root!a\' {',
                    'export function browser (): boolean',
                    '}',
                    'declare module \'root!b\' {',
                    'export const bar: boolean',
                    '}',
                    'declare module \'root!dep/path\' {',
                    'export const isDep: boolean',
                    '}',
                    'declare module \'root/root-import\' {',
                    'export const test: string',
                    '}',
                    'declare module \'root/root\' {',
                    'import a from \'root!a\'',
                    'import b = require(\'root!b\')',
                    'import { isDep } from \'root!dep/path\'',
                    'export * from \'root/root-import\'',
                    '}',
                    'declare module \'root\' {',
                    'export * from \'root/root\';',
                    '}'
                ].join(os_1.EOL));
            });
        });
        t.test('compile export equals', function (t) {
            var FIXTURE_DIR = path_1.join(FIXTURES_DIR, 'compile-export-equals');
            var file = {
                type: config_1.PROJECT_NAME,
                src: path_1.join(FIXTURE_DIR, config_1.CONFIG_FILE),
                missing: false,
                ambient: false,
                main: 'file.d.ts',
                dependencies: {},
                devDependencies: {},
                ambientDependencies: {}
            };
            return compile_1.default(file, { name: 'foobar', cwd: __dirname, ambient: false })
                .then(function (results) {
                t.equal(results.main, [
                    'declare module \'foobar/file\' {',
                    'function foo (value: string): foo.Bar;',
                    '',
                    'module foo {',
                    '  export interface Bar {',
                    '    (message: any, ...args: any[]): void;',
                    '    enabled: boolean;',
                    '    namespace: string;',
                    '  }',
                    '}',
                    '',
                    'export = foo;',
                    '}',
                    'declare module \'foobar\' {',
                    'import main = require(\'foobar/file\');',
                    'export = main;',
                    '}'
                ].join(os_1.EOL));
            });
        });
        t.test('compile an ambient definition', function (t) {
            var FIXTURE_DIR = path_1.join(FIXTURES_DIR, 'compile-ambient');
            var node = {
                type: config_1.PROJECT_NAME,
                src: __filename,
                missing: false,
                ambient: true,
                typings: path_1.join(FIXTURE_DIR, 'node.d.ts'),
                dependencies: {},
                devDependencies: {},
                ambientDependencies: {}
            };
            var fs = {
                type: config_1.PROJECT_NAME,
                src: path_1.join(FIXTURE_DIR, 'fs.d.ts'),
                missing: false,
                ambient: false,
                main: undefined,
                typings: path_1.join(FIXTURE_DIR, 'fs.d.ts'),
                dependencies: {},
                devDependencies: {},
                ambientDependencies: {}
            };
            node.dependencies.fs = fs;
            return compile_1.default(node, { name: 'name', cwd: __dirname, ambient: true })
                .then(function (result) {
                t.equal(result.main, [
                    'declare module \'fs\' {',
                    'export function readFileSync (path: string, encoding: string): string',
                    'export function readFileSync (path: string): Buffer',
                    '}',
                    'declare var __dirname: string'
                ].join(os_1.EOL));
            });
        });
        t.test('compile inline ambient definitions', function (t) {
            var FIXTURE_DIR = path_1.join(FIXTURES_DIR, 'compile-inline-ambient');
            var typings = path_1.join(FIXTURE_DIR, 'node.d.ts');
            var node = {
                type: config_1.PROJECT_NAME,
                src: __filename,
                missing: false,
                ambient: true,
                typings: typings,
                dependencies: {},
                devDependencies: {},
                ambientDependencies: {}
            };
            return Promise.all([
                compile_1.default(node, { name: 'name', cwd: __dirname, ambient: true }),
                fs_1.readFile(typings, 'utf8')
            ])
                .then(function (_a) {
                var _b = _a === void 0 ? [] : _a, result = _b[0], contents = _b[1];
                t.equal(result.main + "\n", contents);
                t.equal(result.browser + "\n", contents);
            });
        });
    });
});
//# sourceMappingURL=compile.spec.js.map