var test = require('blue-tape');
var path_1 = require('path');
var dependencies_1 = require('./dependencies');
var config_1 = require('../utils/config');
var CACHE_PATH = path_1.join(__dirname, '.cache');
var RESOLVE_FIXTURE_DIR = path_1.join(__dirname, '__test__/fixtures/resolve');
test('dependencies', function (t) {
    t.test('resolve fixture', function (t) {
        t.test('resolve a dependency tree', function (t) {
            var expected = {
                type: undefined,
                ambient: false,
                missing: false,
                name: undefined,
                src: undefined,
                main: undefined,
                browser: undefined,
                typings: undefined,
                browserTypings: undefined,
                dependencies: {},
                devDependencies: {},
                ambientDependencies: {}
            };
            var bowerDep = {
                type: 'bower',
                ambient: false,
                missing: false,
                src: path_1.join(RESOLVE_FIXTURE_DIR, 'bower_components/bower-dep/bower.json'),
                typings: 'bower-dep.d.ts',
                browserTypings: undefined,
                dependencies: {},
                devDependencies: {},
                ambientDependencies: {},
                name: 'bower-dep',
                version: undefined,
                main: 'index.js',
                browser: undefined
            };
            var exampleDep = {
                type: 'bower',
                ambient: false,
                missing: false,
                src: path_1.join(RESOLVE_FIXTURE_DIR, 'bower_components/example/bower.json'),
                main: undefined,
                browser: undefined,
                version: undefined,
                typings: undefined,
                browserTypings: undefined,
                name: 'example',
                dependencies: {},
                devDependencies: {},
                ambientDependencies: {}
            };
            var typedDep = {
                type: config_1.PROJECT_NAME,
                ambient: false,
                missing: false,
                src: path_1.join(RESOLVE_FIXTURE_DIR, 'typings/dep.d.ts'),
                typings: path_1.join(RESOLVE_FIXTURE_DIR, 'typings/dep.d.ts'),
                dependencies: {},
                devDependencies: {},
                ambientDependencies: {}
            };
            var npmDep = {
                type: 'npm',
                ambient: false,
                missing: false,
                src: path_1.join(RESOLVE_FIXTURE_DIR, 'node_modules/npm-dep/package.json'),
                main: './index.js',
                browser: undefined,
                version: undefined,
                typings: undefined,
                browserTypings: undefined,
                name: 'npm-dep',
                dependencies: {},
                devDependencies: {},
                ambientDependencies: {}
            };
            var typedDevDep = {
                type: 'bower',
                ambient: false,
                missing: true,
                src: path_1.join(RESOLVE_FIXTURE_DIR, 'bower_components/dep/bower.json'),
                dependencies: {},
                devDependencies: {},
                ambientDependencies: {}
            };
            expected.dependencies['bower-dep'] = bowerDep;
            expected.dependencies['dep'] = typedDep;
            expected.dependencies['npm-dep'] = npmDep;
            expected.devDependencies['dev-dep'] = typedDevDep;
            bowerDep.dependencies['example'] = exampleDep;
            return dependencies_1.default({
                cwd: RESOLVE_FIXTURE_DIR,
                dev: true
            })
                .then(function (result) {
                function removeParentReferenceFromDependencies(dependencies) {
                    Object.keys(dependencies).forEach(function (key) {
                        removeParentReference(dependencies[key]);
                    });
                }
                function removeParentReference(tree) {
                    delete tree.parent;
                    removeParentReferenceFromDependencies(tree.dependencies);
                    removeParentReferenceFromDependencies(tree.devDependencies);
                    removeParentReferenceFromDependencies(tree.ambientDependencies);
                    return tree;
                }
                removeParentReference(result);
                t.deepEqual(result, expected);
            });
        });
    });
});
//# sourceMappingURL=dependencies.spec.js.map