var test = require('blue-tape');
var path_1 = require('path');
var parse_1 = require('./parse');
var config_1 = require('./config');
test('parse', function (t) {
    t.test('parse dependency', function (t) {
        t.test('parse filename', function (t) {
            var actual = parse_1.parseDependency('file:./foo/bar.d.ts');
            var expected = {
                raw: 'file:./foo/bar.d.ts',
                location: path_1.normalize('foo/bar.d.ts'),
                type: 'file'
            };
            t.deepEqual(actual, expected);
            t.end();
        });
        t.test('parse filename relative', function (t) {
            var actual = parse_1.parseDependency('file:foo/bar.d.ts');
            var expected = {
                raw: 'file:foo/bar.d.ts',
                location: path_1.normalize('foo/bar.d.ts'),
                type: 'file'
            };
            t.deepEqual(actual, expected);
            t.end();
        });
        t.test('parse npm', function (t) {
            var actual = parse_1.parseDependency('npm:foobar');
            var expected = {
                raw: 'npm:foobar',
                type: 'npm',
                location: path_1.normalize('foobar/package.json')
            };
            t.deepEqual(actual, expected);
            t.end();
        });
        t.test('parse scoped npm packages', function (t) {
            var actual = parse_1.parseDependency('npm:@foo/bar');
            var expected = {
                raw: 'npm:@foo/bar',
                type: 'npm',
                location: path_1.normalize('@foo/bar/package.json')
            };
            t.deepEqual(actual, expected);
            t.end();
        });
        t.test('parse npm filename', function (t) {
            var actual = parse_1.parseDependency('npm:typescript/bin/lib.es6.d.ts');
            var expected = {
                raw: 'npm:typescript/bin/lib.es6.d.ts',
                type: 'npm',
                location: path_1.normalize('typescript/bin/lib.es6.d.ts')
            };
            t.deepEqual(actual, expected);
            t.end();
        });
        t.test('parse bower', function (t) {
            var actual = parse_1.parseDependency('bower:foobar');
            var expected = {
                raw: 'bower:foobar',
                type: 'bower',
                location: path_1.normalize('foobar/bower.json')
            };
            t.deepEqual(actual, expected);
            t.end();
        });
        t.test('parse bower filename', function (t) {
            var actual = parse_1.parseDependency('bower:foobar/' + config_1.CONFIG_FILE);
            var expected = {
                raw: 'bower:foobar/' + config_1.CONFIG_FILE,
                type: 'bower',
                location: path_1.normalize('foobar/' + config_1.CONFIG_FILE)
            };
            t.deepEqual(actual, expected);
            t.end();
        });
        t.test('parse github', function (t) {
            var actual = parse_1.parseDependency('github:foo/bar');
            var expected = {
                raw: 'github:foo/bar',
                type: 'hosted',
                location: 'https://raw.githubusercontent.com/foo/bar/master/' + config_1.CONFIG_FILE
            };
            t.deepEqual(actual, expected);
            t.end();
        });
        t.test('parse github with she and append `` + CONFIG_FILE', function (t) {
            var actual = parse_1.parseDependency('github:foo/bar#test');
            var expected = {
                raw: 'github:foo/bar#test',
                type: 'hosted',
                location: 'https://raw.githubusercontent.com/foo/bar/test/' + config_1.CONFIG_FILE
            };
            t.deepEqual(actual, expected);
            t.end();
        });
        t.test('parse github paths to `.d.ts` files', function (t) {
            var actual = parse_1.parseDependency('github:foo/bar/typings/file.d.ts');
            var expected = {
                raw: 'github:foo/bar/typings/file.d.ts',
                type: 'hosted',
                location: 'https://raw.githubusercontent.com/foo/bar/master/typings/file.d.ts'
            };
            t.deepEqual(actual, expected);
            t.end();
        });
        t.test('parse github paths to `` + CONFIG_FILE', function (t) {
            var actual = parse_1.parseDependency('github:foo/bar/src/' + config_1.CONFIG_FILE);
            var expected = {
                raw: 'github:foo/bar/src/' + config_1.CONFIG_FILE,
                type: 'hosted',
                location: 'https://raw.githubusercontent.com/foo/bar/master/src/' + config_1.CONFIG_FILE
            };
            t.deepEqual(actual, expected);
            t.end();
        });
        t.test('parse bitbucket', function (t) {
            var actual = parse_1.parseDependency('bitbucket:foo/bar');
            var expected = {
                raw: 'bitbucket:foo/bar',
                type: 'hosted',
                location: 'https://bitbucket.org/foo/bar/raw/master/' + config_1.CONFIG_FILE
            };
            t.deepEqual(actual, expected);
            t.end();
        });
        t.test('parse bitbucket and append `` + CONFIG_FILE to path', function (t) {
            var actual = parse_1.parseDependency('bitbucket:foo/bar/dir');
            var expected = {
                raw: 'bitbucket:foo/bar/dir',
                type: 'hosted',
                location: 'https://bitbucket.org/foo/bar/raw/master/dir/' + config_1.CONFIG_FILE
            };
            t.deepEqual(actual, expected);
            t.end();
        });
        t.test('parse bitbucket with sha', function (t) {
            var actual = parse_1.parseDependency('bitbucket:foo/bar#abc');
            var expected = {
                raw: 'bitbucket:foo/bar#abc',
                type: 'hosted',
                location: 'https://bitbucket.org/foo/bar/raw/abc/' + config_1.CONFIG_FILE
            };
            t.deepEqual(actual, expected);
            t.end();
        });
        t.test('parse url', function (t) {
            var actual = parse_1.parseDependency('http://example.com/foo/' + config_1.CONFIG_FILE);
            var expected = {
                raw: 'http://example.com/foo/' + config_1.CONFIG_FILE,
                type: 'hosted',
                location: 'http://example.com/foo/' + config_1.CONFIG_FILE
            };
            t.deepEqual(actual, expected);
            t.end();
        });
        t.test('unsupported scheme', function (t) {
            t.throws(function () { return parse_1.parseDependency('random:fake/dep'); }, /Unsupported dependency/);
            t.end();
        });
    });
});
//# sourceMappingURL=parse.spec.js.map